@@ -1,6 +1,6 @@
 package ETL::Yertl;
 # ABSTRACT: ETL with a Shell
-$ETL::Yertl::VERSION = '0.020';
+$ETL::Yertl::VERSION = '0.021';
 use strict;
 use warnings;
 use base 'Import::Base';
@@ -55,7 +55,7 @@ ETL::Yertl - ETL with a Shell
 
 =head1 VERSION
 
-version 0.020
+version 0.021
 
 =head1 SYNOPSIS
 
@@ -71,11 +71,14 @@ version 0.020
     $ yto csv work.yml
     $ yto json work.yml
 
+    # Parse HTTP logs into documents
+    $ ygrok '%{LOG.HTTP_COMMON}' httpd.log
+
     # Read data from a database
-    $ ysql query devdb 'SELECT * FROM employee'
+    $ ysql db_name 'SELECT * FROM employee'
 
     # Write data to a database
-    $ ysql query devdb 'INSERT INTO employee ( id, name ) VALUES ( $.id, $.name )'
+    $ ysql db_name 'INSERT INTO employee ( id, name ) VALUES ( $.id, $.name )'
 
     ### In Perl...
     use ETL::Yertl;
@@ -126,6 +129,10 @@ Convert incoming data (CSV, JSON) to Yertl documents.
 
 Convert Yertl documents into another format (CSV, JSON).
 
+=item L<ygrok>
+
+Parse lines of text into Yertl documents.
+
 =item L<ysql>
 
 Read/write documents from SQL databases.
@@ -157,12 +164,6 @@ for L<yq>.
 
 Doug Bell <preaction@cpan.org>
 
-=head1 CONTRIBUTOR
-
-=for stopwords Doug Bell
-
-Doug Bell <preaction@users.noreply.github.com>
-
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2015 by Doug Bell.
